@@ -22,7 +22,7 @@ module Devise
       def validate_otp(resource)
         return true unless resource.otp_required_for_login
         return if params[scope]['otp_attempt'].nil?
-        resource.valid_otp?(params[scope]['otp_attempt'])
+        resource.validate_and_consume_otp!(params[scope]['otp_attempt'])
       end
     end
   end
